PyXMake Developer Guide: PyXMake.VTL.stm_make.doxy_mcdcore Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.doxy_mcdcore Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.doxy_mcdcore:

## Public Attributes
str | brief = "MCODAC"
str | header = "MCODAC Developer Guide"
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_doxygen
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
str | stype = "Fortran"
| scratch_path = os.getcwd()
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_doxygen
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
int | _KEY_OPT = 0
str | _BUILD_NAME = 'mcd_core'
| _INPUT_FILES = GetSourceCode(_KEY_OPT)
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_doxygen
str | _BUILD_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_doxygen
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_doxygen
str | description = "Runs the html documentation build process of source code using Doxygen."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Runs the html documentation build process for MCODAC.

Definition at line 490 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.doxy_mcdcore._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 501 of file stm_make.py.

## Member Data Documentation

## ◆ _BUILD_NAME

str PyXMake.VTL.stm_make.doxy_mcdcore._BUILD_NAME = 'mcd_core'
| staticprotected

Definition at line 497 of file stm_make.py.

## ◆ _INPUT_FILES

PyXMake.VTL.stm_make.doxy_mcdcore._INPUT_FILES = GetSourceCode(_KEY_OPT)
| staticprotected

Definition at line 499 of file stm_make.py.

## ◆ _KEY_OPT

int PyXMake.VTL.stm_make.doxy_mcdcore._KEY_OPT = 0
| staticprotected

Definition at line 496 of file stm_make.py.

## ◆ brief

str PyXMake.VTL.stm_make.doxy_mcdcore.brief = "MCODAC"

Definition at line 502 of file stm_make.py.

## ◆ header

str PyXMake.VTL.stm_make.doxy_mcdcore.header = "MCODAC Developer Guide"

Definition at line 503 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py